@@ -1,5 +1,6 @@
 from systemd import SystemD
 from gitbucket import config
+from gitbucket_web import GitBucket
 
 SERVICE_NAME = 'gitbucket'
 PROTOCOL = 'http'
@@ -7,17 +8,30 @@ SERVICE_TYPE = '_gitbucket._http._tcp'
 PORT = 81
 URL = None
 
+USER_URL = 'http://syncloud.it'
+DEFAULT_LOGIN = 'root'
+DEFAULT_PASSWORD = 'root'
+
 class GitbucketControl:
     def __init__(self, insider):
-        self.systemd = SystemD()
+        self.systemd = SystemD('gitbucket.service')
         self.insider = insider
 
-    def enable(self):
+    def enable(self, login, password):
         gb_config = config.read_config()
         gb_config.port = PORT
         config.write_config(gb_config)
         self.systemd.enable()
         self.systemd.start()
+
+        gb = GitBucket('http://localhost:{}'.format(PORT), USER_URL)
+        gb.wait(timeout=60, check_period=5)
+        if login == DEFAULT_LOGIN:
+            gb.change_password(DEFAULT_LOGIN, DEFAULT_PASSWORD, password)
+        else:
+            gb.create_account(login, password)
+            gb.disable_account(login, password, user_name_to_disable=DEFAULT_LOGIN)
+
         self.insider.add_service(SERVICE_NAME, PROTOCOL, SERVICE_TYPE, PORT, URL)
 
     def disable(self):
